@@ -9,16 +9,16 @@ the necessary mechanisms to generate random instances of the described space.
 
 # The [`sampler`](ref:search_space.sampler.__init__) submodule allows us to
 # define the protocols for random number generation and selection of options.
-from . import sampler
+from search_space import sampler
 
-from . import context_manager
+from search_space import context_manager
 
-from . import dsl
+from search_space.dsl import Domain, RandomValue
 
-from . import errors
+from search_space import errors
 
-from . import functions
+from search_space import functions
 
-from . import spaces
+from search_space import spaces
 
-from . import utils
+from search_space import utils
